#!/usr/bin/ruby env
# Configuration file for packbench

# Temporary file, can be with path
TMPFILE = "packbench-#{Time.now.to_i.to_s}-#{rand(99999).to_s}.tmp"

# Files to compress and decompress
FILES = [
	"coreutils-8.5.tar"
]

# Packers to be used
# Use COMPRESSVARIANT in "compress" to tell packbench
# where to place the options in "compressvariants", if omitted
# it places them directly after the "compress" command.
#
# Add "skip" => true, to a packer, if you want to skip it
# 
# "version" output should be fitting on one line. packbench
# replaced /n by " - " to bring two lines onto one line
PACKERS = [
	{
		"name" => "gzip",
		"extension" => ".gz",
		"version" => "gzip --version | head -1",
		"compress" => "gzip",
		"compressvariants" => [ "-6", "-1", "-9" ],
		"decompress" => "gzip -d",
	},
	{
		"name" => "bzip2",
		"extension" => ".bz2",
		"version"	=> "bzip2 --version 2>&1 | head -1",
		"compress" => "bzip2",
		"compressvariants" => [ "-6", "-1", "-9" ],
		"decompress" => "bzip2 -d"
	},
	{
		"name" => "pbzip2",
		"extension" => ".bz2",
		"version" => "pbzip2 --version 2>&1 | head -1",
		"compress" => "pbzip2",
		"compressvariants" => [ "-9", "-1", "-6" ],
		"decompress" => "pbzip2 -d"
	},
	{
		"name" => "lbzip2",
		"extension" => ".bz2",
		"version" => "lbzip2 --version 2>&1 | grep Version",
		"compress" => "lbzip2",
		"compressvariants" => [ "-9", "-1", "-6" ],
		"decompress" => "lbzip2 -d"
	},
	{
		"name" => "xz",
		"extension" => ".xz",
		"version" => "xz --version | head -2",
		"compress" => "xz",
		"compressvariants" => [ "-6", "-1", "-2", "-9" ],
		"decompress" => "xz -d"
	},
	{
		"name" => "zip",
		"extension" => ".zip",
		"version" => "zip --version | grep \"This is\"",
		"compress" => "zip COMPRESSVARIANT #{TMPFILE}.zip",
		"compressvariants" => [ "-6", "-1", "-9" ],
		"decompress" => "unzip"
	},
	{
		"name" => "lzip",
		"extension" => ".lz",
		"version" => "lzip --version | head -1",
		"compress" => "lzip",
		"compressvariants" => [ "-6", "-1", "-9" ],
		"decompress" => "lzip -d"
	},
	{
		"name" => "7zip",
		"extension" => ".7z",
		"version" => "7z | grep Copyright",
		# -mmt=on enables multithreading!
		"compress" => "7z a -mmt=on COMPRESSVARIANT #{TMPFILE}.7z",
		"compressvariants" => [ "-mx=5", "-mx=1", "-mx=9" ],
		"decompress" => "7z e",
	},
	{
		"name" => "lzma",
		"extension" => ".lzma",
		"version" => "lzma --version | head -1",
		"compress" => "lzma",
		"compressvariants" => [ "", "-1", "-9" ],
		"decompress" => "lzma -d"
	},
	{
		"name" => "lzop",
		"extension" => ".lzo",
		"version" => "lzop --version | head -2",
		"compress" => "lzop -U",
		"compressvariants" => [ "-3", "-1", "-9" ],
		"decompress" => "lzop -d -U"
	},
	{
		"name" => "lrzip",
		"extension" => ".lrz",
		"version" => "lrzip -V 2>&1",
		"compress" => "lrzip",
		"compressvariants" => [ "-L 7", "-L 1", "-L 9" ],
		"decompress" => "lrzip -d"
	},
    	{
		"name" => "rar",
		"extension" => ".rar",
		"version" => "rar | grep Copyright",
		"compress" => "rar a COMPRESSVARIANT #{TMPFILE}.rar",
		"compressvariants" => [ "-m3", "-m1", "-m5" ],
		"decompress" => "rar e"
	},
	{
		"name" => "paq8l",
		"extension" => ".paq8l",
		"version" => "paq8l | head -1",
		"compress" => "paq8l",
		"compressvariants" => [ "-5", "-1", "-7" ], # "-8" uses 1643 MiB RAM instead of 837 MiB and causes to much swapping on my ThinkPad T42 with 2 GiB RAM
		"decompress" => "paq8l",
		"keypress" => "enter"	# needs pressing the enter key after each invocation
	},
	{
		"name" => "zp",
		"extension" => ".zpaq",
		"version" => "zp | grep \"(C)\"",
		"compress" => "zp COMPRESSVARIANT #{TMPFILE}.zpaq",
		"compressvariants" => [ "c1", "c2", "c3" ],
		"decompress" => "zp x"
	},
	{
		"name" => "zpaq",
		"extension" => ".zpaq",
		"version" => "zpaq | grep \"(C)\"",
		# zp is more userfriendly and comes with pre-compiled defaults
		# but then zpaq allows specifying maximum compression with
		# even higher memory usage
		# "skip" => true,
		"compress" => "zpaq COMPRESSVARIANT #{TMPFILE}.zpaq",
		# Add "o" if you want to use zpaqmake and a C++ compiler to 
		# speed up compression and decompression
		"compressvariants" => ["qc/usr/share/doc/zpaq/examples/max.cfg", "qc/usr/share/doc/zpaq/examples/max.cfg,1", "qc/usr/share/doc/zpaq/examples/max.cfg,2" ], #  "qc/usr/share/doc/zpaq/examples/max.cfg,3" uses 1861 MiB instead of 938 MiB and causes to much swapping on my ThinkPad T42 with 2 GiB RAM
		"decompress" => "zpaq x"
	}, 
	{
		"name" => "kgb",
		"extension" => ".kgb",
		"version" => "kgb| grep \"(C)\"",
		"compress" => "kgb COMPRESSVARIANT #{TMPFILE}.kgb",
		"compressvariants" => [ "-3", "-0", "-8" ], # "-9"  uses 1616 MiB RAM instead of 808 MiB and causes to much swapping on my ThinkPad T42 with 2 GiB RAM
		"decompress" => "kgb"
	}
]

