#!/bin/sh
#
# release.sh: Release script for packbench
#
# Creates release archives in various formats, md5- and sha1sums them
# and signs the hash sum files.
#
# Packbench compresses and decompresses several files with different
# packers and options. It then displays packed size, elapsed time,
# cpu usage in a nice table.
#
# Copyright © 2009-2010 Martin Steigerwald <Martin@Lichtvoll.de>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

VERSION=$(grep "^APPVERSION" packbench | cut -d\" -f2)
echo "Creating release for packbench $VERSION."

DIR=packbench-$VERSION
mkdir -p "$DIR"

ARCHIVEDIR=releases
mkdir -p $ARCHIVEDIR
ARCHIVE=$ARCHIVEDIR/packbench-$VERSION.tar

# Fill release version directory with the stuff to release
cp -p packbench "$DIR"
cp -p packbench-config.rb "$DIR"
cp -p changelog "$DIR"
cp -a example-benchmarks "$DIR"

cp -p README "$DIR"
cp -p GPL_V3 "$DIR"

# In case someone else wants to release a version.
cp -p release.sh "$DIR"

rm ${ARCHIVE}.*

# gzip
tar -cvzf "$ARCHIVE".gz "$DIR" >/dev/null
# bzip2
tar -cvjf "$ARCHIVE".bz2 "$DIR" >/dev/null
# xz
tar -cvJf "$ARCHIVE".xz "$DIR" >/dev/null
# lzma
tar --lzma -cvf "$ARCHIVE".lzma "$DIR" >/dev/null
# lzip
tar --lzip -cvf "$ARCHIVE".lzip "$DIR" >/dev/null
# lzop
tar --lzop -cvf "$ARCHIVE".lzop "$DIR" >/dev/null

for FILE in ${ARCHIVE}.*; do
	md5sum "$FILE" >"$FILE".md5
	sha1sum "$FILE" >"$FILE".sha1
	gpg --armor --sign "$FILE".md5
	gpg --armor --sign "$FILE".sha1
done

rm -r "$DIR"

